@@ -13,13 +13,15 @@
       '.*',
       {
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'uniline',
+        'warn' => 'Unknown parameter'
       }
     ],
     'class_description' => 'A unit configuration file whose name ends in
 C<.socket> encodes information about an IPC or
 network socket or a file system FIFO controlled and supervised by
 systemd, for socket-based activation.
+
 This man page lists the configuration options specific to
 this unit type. See
 L<systemd.unit(5)>
@@ -27,6 +29,7 @@ for the common options of all unit configuration files. The common
 configuration items are configured in the generic [Unit] and
 [Install] sections. The socket specific configuration options are
 configured in the [Socket] section.
+
 Additional options are listed in
 L<systemd.exec(5)>,
 which define the execution environment the
@@ -38,6 +41,7 @@ which define the way the processes are terminated, and in
 L<systemd.resource-control(5)>,
 which configure resource control settings for the processes of the
 socket.
+
 For each socket file, a matching service file must exist,
 describing the service to start on incoming traffic on the socket
 (see
@@ -56,12 +60,14 @@ C<Accept=false> is set. If
 C<Accept=true> is set, a service template file
 foo@.service must exist from which services
 are instantiated for each incoming connection.
+
 Unless C<DefaultDependencies> in the C<[Unit]> section is set to
 C<false>, socket units will implicitly have dependencies of type C<Requires> and
 C<After> on sysinit.target as well as dependencies of type
 C<Conflicts> and C<Before> on shutdown.target. These ensure
 that socket units pull in basic system initialization, and are terminated cleanly prior to system shutdown. Only
 sockets involved with early boot or late system shutdown should disable this option.
+
 Socket units will have a C<Before>
 dependency on the service which they trigger added implicitly. No
 implicit C<WantedBy> or
@@ -70,9 +76,11 @@ service is added. This means that the service may be started
 without the socket, in which case it must be able to open sockets
 by itself. To prevent this, an explicit
 C<Requires> dependency may be added.
+
 Socket units may be used to implement on-demand starting of
 services, as well as parallelized starting of services. See the
 blog stories linked at the end for an introduction.
+
 Note that the daemon software configured for socket
 activation with socket units needs to be able to accept sockets
 from systemd, either via systemd\'s native socket passing interface
@@ -101,44 +109,60 @@ by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-
 (C<SOCK_STREAM>), datagram
 (C<SOCK_DGRAM>), or sequential packet
 (C<SOCK_SEQPACKET>) socket, respectively.
-The address can be written in various formats:If the address starts with a slash
+The address can be written in various formats:
+
+If the address starts with a slash
 (C</>), it is read as file system socket in
-the C<AF_UNIX> socket family.If the address starts with an at symbol
+the C<AF_UNIX> socket family.
+
+If the address starts with an at symbol
 (C<@>), it is read as abstract namespace
 socket in the C<AF_UNIX> family. The
 C<@> is replaced with a
 C<NUL> character before binding. For
 details, see
-L<unix(7)>.If the address string is a single number, it is read as
+L<unix(7)>.
+
+If the address string is a single number, it is read as
 port number to listen on via IPv6. Depending on the value of
 C<BindIPv6Only> (see below) this might result
 in the service being available via both IPv6 and IPv4
 (default) or just via IPv6.
+
 If the address string is a string in the format
 v.w.x.y:z, it is read as IPv4 specifier for listening on an
-address v.w.x.y on a port z.If the address string is a string in the format [x]:y,
+address v.w.x.y on a port z.
+
+If the address string is a string in the format [x]:y,
 it is read as IPv6 address x on a port y. Note that this might
 make the service available via IPv4, too, depending on the
 C<BindIPv6Only> setting (see below).
+
 Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
 for C<AF_UNIX> sockets.
 C<SOCK_STREAM> (i.e.
 C<ListenStream>) when used for IP sockets
 refers to TCP sockets, C<SOCK_DGRAM> (i.e.
-C<ListenDatagram>) to UDP.These options may be specified more than once, in which
+C<ListenDatagram>) to UDP.
+
+These options may be specified more than once, in which
 case incoming traffic on any of the sockets will trigger
 service activation, and all listed sockets will be passed to
 the service, regardless of whether there is incoming traffic
 on them or not. If the empty string is assigned to any of
 these options, the list of addresses to listen on is reset,
 all prior uses of any of these options will have no
-effect.It is also possible to have more than one socket unit
+effect.
+
+It is also possible to have more than one socket unit
 for the same service when using C<Service>,
 and the service will receive all the sockets configured in all
 the socket units. Sockets configured in one unit are passed in
 the order of configuration, but no ordering between socket
-units is specified.If an IP address is used here, it is often desirable to
+units is specified.
+
+If an IP address is used here, it is often desirable to
 listen on it before the interface it is configured on is up
 and running, and even regardless of whether it will be up and
 running at any point. To deal with this, it is recommended to
@@ -156,44 +180,60 @@ below.',
 (C<SOCK_STREAM>), datagram
 (C<SOCK_DGRAM>), or sequential packet
 (C<SOCK_SEQPACKET>) socket, respectively.
-The address can be written in various formats:If the address starts with a slash
+The address can be written in various formats:
+
+If the address starts with a slash
 (C</>), it is read as file system socket in
-the C<AF_UNIX> socket family.If the address starts with an at symbol
+the C<AF_UNIX> socket family.
+
+If the address starts with an at symbol
 (C<@>), it is read as abstract namespace
 socket in the C<AF_UNIX> family. The
 C<@> is replaced with a
 C<NUL> character before binding. For
 details, see
-L<unix(7)>.If the address string is a single number, it is read as
+L<unix(7)>.
+
+If the address string is a single number, it is read as
 port number to listen on via IPv6. Depending on the value of
 C<BindIPv6Only> (see below) this might result
 in the service being available via both IPv6 and IPv4
 (default) or just via IPv6.
+
 If the address string is a string in the format
 v.w.x.y:z, it is read as IPv4 specifier for listening on an
-address v.w.x.y on a port z.If the address string is a string in the format [x]:y,
+address v.w.x.y on a port z.
+
+If the address string is a string in the format [x]:y,
 it is read as IPv6 address x on a port y. Note that this might
 make the service available via IPv4, too, depending on the
 C<BindIPv6Only> setting (see below).
+
 Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
 for C<AF_UNIX> sockets.
 C<SOCK_STREAM> (i.e.
 C<ListenStream>) when used for IP sockets
 refers to TCP sockets, C<SOCK_DGRAM> (i.e.
-C<ListenDatagram>) to UDP.These options may be specified more than once, in which
+C<ListenDatagram>) to UDP.
+
+These options may be specified more than once, in which
 case incoming traffic on any of the sockets will trigger
 service activation, and all listed sockets will be passed to
 the service, regardless of whether there is incoming traffic
 on them or not. If the empty string is assigned to any of
 these options, the list of addresses to listen on is reset,
 all prior uses of any of these options will have no
-effect.It is also possible to have more than one socket unit
+effect.
+
+It is also possible to have more than one socket unit
 for the same service when using C<Service>,
 and the service will receive all the sockets configured in all
 the socket units. Sockets configured in one unit are passed in
 the order of configuration, but no ordering between socket
-units is specified.If an IP address is used here, it is often desirable to
+units is specified.
+
+If an IP address is used here, it is often desirable to
 listen on it before the interface it is configured on is up
 and running, and even regardless of whether it will be up and
 running at any point. To deal with this, it is recommended to
@@ -211,44 +251,60 @@ below.',
 (C<SOCK_STREAM>), datagram
 (C<SOCK_DGRAM>), or sequential packet
 (C<SOCK_SEQPACKET>) socket, respectively.
-The address can be written in various formats:If the address starts with a slash
+The address can be written in various formats:
+
+If the address starts with a slash
 (C</>), it is read as file system socket in
-the C<AF_UNIX> socket family.If the address starts with an at symbol
+the C<AF_UNIX> socket family.
+
+If the address starts with an at symbol
 (C<@>), it is read as abstract namespace
 socket in the C<AF_UNIX> family. The
 C<@> is replaced with a
 C<NUL> character before binding. For
 details, see
-L<unix(7)>.If the address string is a single number, it is read as
+L<unix(7)>.
+
+If the address string is a single number, it is read as
 port number to listen on via IPv6. Depending on the value of
 C<BindIPv6Only> (see below) this might result
 in the service being available via both IPv6 and IPv4
 (default) or just via IPv6.
+
 If the address string is a string in the format
 v.w.x.y:z, it is read as IPv4 specifier for listening on an
-address v.w.x.y on a port z.If the address string is a string in the format [x]:y,
+address v.w.x.y on a port z.
+
+If the address string is a string in the format [x]:y,
 it is read as IPv6 address x on a port y. Note that this might
 make the service available via IPv4, too, depending on the
 C<BindIPv6Only> setting (see below).
+
 Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
 for C<AF_UNIX> sockets.
 C<SOCK_STREAM> (i.e.
 C<ListenStream>) when used for IP sockets
 refers to TCP sockets, C<SOCK_DGRAM> (i.e.
-C<ListenDatagram>) to UDP.These options may be specified more than once, in which
+C<ListenDatagram>) to UDP.
+
+These options may be specified more than once, in which
 case incoming traffic on any of the sockets will trigger
 service activation, and all listed sockets will be passed to
 the service, regardless of whether there is incoming traffic
 on them or not. If the empty string is assigned to any of
 these options, the list of addresses to listen on is reset,
 all prior uses of any of these options will have no
-effect.It is also possible to have more than one socket unit
+effect.
+
+It is also possible to have more than one socket unit
 for the same service when using C<Service>,
 and the service will receive all the sockets configured in all
 the socket units. Sockets configured in one unit are passed in
 the order of configuration, but no ordering between socket
-units is specified.If an IP address is used here, it is often desirable to
+units is specified.
+
+If an IP address is used here, it is often desirable to
 listen on it before the interface it is configured on is up
 and running, and even regardless of whether it will be up and
 running at any point. To deal with this, it is recommended to
@@ -440,7 +496,9 @@ C<Accept=true> is mostly useful to allow
 daemons designed for usage with
 L<inetd(8)>
 to work unmodified with systemd socket
-activation.For IPv4 and IPv6 connections, the C<REMOTE_ADDR>
+activation.
+
+For IPv4 and IPv6 connections, the C<REMOTE_ADDR>
 environment variable will contain the remote IP address, and C<REMOTE_PORT>
 will contain the remote port. This is the same as the format used by CGI.
 For SOCK_RAW, the port is the IP protocol.',
@@ -584,11 +642,14 @@ option is beneficial for protocols where the client sends the
 data first (e.g. HTTP, in contrast to SMTP), because the
 server process will not be woken up unnecessarily before it
 can take any action.
+
 If the client also uses the
 C<TCP_DEFER_ACCEPT> option, the latency of
 the initial connection may be reduced, because the kernel will
 send data in the final packet establishing the connection (the
-third packet in the "three-way handshake").Disabled by default.',
+third packet in the "three-way handshake").
+
+Disabled by default.',
         'type' => 'leaf',
         'value_type' => 'integer'
       },
